==> sale-1.11.70.jar: revenue/sqls/charge/getUser.sql <==
select
  i.f_userinfo_code,
  i.f_userinfo_id,
  i.f_user_state,
  i.f_user_name,
  i.f_user_phone,
  i.f_balance,
  i.f_idnumber,
  i.f_credentials,
  i.version as userinfo_version,
  i.f_comments,
  u.f_user_id,
  u.f_table_state,
  u.f_card_id,
  u.f_card_password,
  u.f_meterid,
  u.f_meternumber,
  u.f_metertitles,
  u.f_times,
  u.f_fillcard_times,
  u.f_price_id,
  u.f_gasbrand_id,
  u.f_gasmodel_id,
  u.f_user_type,
  u.f_gasproperties,
  u.f_meter_base,
  u.f_initial_base,
  u.f_total_gas,
  u.f_total_fee,
  u.f_whether_hairpin,
  u.f_balance_amount,
  u.f_balance_gas,
  u.f_remanent_gas,
  u.f_open_date,
  u.version,
  u.f_filialeids,
  u.f_position,
  address.f_address,
  gb.f_meter_type,
  gb.f_meter_brand,
  gb.f_alias,
  gb.f_collection_type,
  gb.f_isdecimal,
  gm.f_meter_style,
  gm.f_calculation,
  gm.f_billing,
  gm.f_coding,
  sp.f_price_type,
  sp.f_price_name,
  sp.f_version,
  sp.f_limit_cycle,
  sp.f_limit_gas
from t_userfiles u
  LEFT JOIN  t_userinfo i
    on u.f_userinfo_id = i.f_userinfo_id
  LEFT JOIN t_user_address address
    on u.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb
    on u.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm
    on u.f_gasmodel_id = gm.id
  LEFT JOIN
  (select * from  t_stairprice
  where getdate()>=f_perform_date and getdate()<=f_end_date
        and f_state = '有效'
  ) sp on u.f_price_id = sp.f_price_id and  u.f_filialeids = sp.f_filialeids
where  {condition}  and f_user_state = '正常'
order by u.f_userinfo_id desc

==> sale-1.12.20-8.jar: revenue/sqls/charge/getUser.sql <==
select
  i.f_userinfo_code,
  i.f_userinfo_id,
  i.f_user_state,
  i.f_user_name,
  i.f_user_phone,
  i.f_balance,
  i.f_idnumber,
  i.f_credentials,
  i.version as userinfo_version,
  u.f_user_id,
  u.f_table_state,
  u.f_card_id,
  u.f_card_password,
  u.f_meterid,
  u.f_area_code,
  u.f_meternumber,
  u.f_metertitles,
  u.f_times,
  u.f_fillcard_times,
  u.f_price_id,
  u.f_gasbrand_id,
  u.f_gasmodel_id,
  u.f_user_type,
  u.f_gasproperties,
  u.f_meter_base,
  u.f_initial_base,
  u.f_total_gas,
  u.f_total_fee,
  u.f_whether_hairpin,
  u.f_balance_amount,
  u.f_balance_gas,
  u.f_remanent_gas,
  u.f_open_date,
  u.version,
  u.f_orgid,
  address.f_address,
  gb.id as brand_id,
  gb.f_meter_type,
  gb.f_meter_brand,
  gb.f_alias,
  gb.f_collection_type,
  gb.f_isdecimal,
  gm.f_meter_style,
  gm.f_calculation,
  gm.f_billing,
  gm.f_coding,
  sp.id as f_stairprice_id,
  sp.f_price_type,
  sp.f_price_name,
  sp.f_version,
   i.f_comments,
   u.f_hiddenTrouble
from t_userfiles u
  LEFT JOIN  t_userinfo i
    on u.f_userinfo_id = i.f_userinfo_id
  LEFT JOIN t_user_address address
    on u.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb
    on u.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm
    on u.f_gasmodel_id = gm.id
  LEFT JOIN
  (select * from  t_stairprice
  where getdate()>=f_perform_date and getdate()<=f_end_date
        and f_state = '有效'
  ) sp on u.f_price_id = sp.f_price_id and  u.f_orgid = sp.f_filialeid
where  {condition}  and f_user_state = '正常'
order by u.f_user_id desc
